import { csvParse } from 'd3';
import { ResponsiveOrdinalFrame } from 'semiotic';
import { data } from './data';
import { colors } from './colors';

const parsedAnswers = csvParse(data);

const atomicData = [];

parsedAnswers.forEach((answer, i) => {
  Object.keys(answer).forEach(key => {
    answer[key] = +answer[key];
    atomicData.push({
      respondent: 'person ' + i,
      response: key,
      value: answer[key]
    });
  });
  answer.respondent = 'person ' + i;
});

ReactDOM.render(
  <div>
    <ResponsiveOrdinalFrame
      size={[960, 500]}
      projection="horizontal"
      data={atomicData}
      oAccessor={'response'}
      rAccessor={'value'}
      summaryType={{ type: 'joy', amplitude: 100 }}
      style={{ fill: 'lightblue', stroke: 'darkblue', opacity: 0.5 }}
      summaryStyle={(d, i) => ({
        fill: colors[i % colors.length],
        stroke: 'grey',
        fillOpacity: 0.75
      })}
      axis={{
        orient: 'left',
        tickValues: [0, 10, 20, 30, 40, 50, 60, 70, 80, 90, 100],
        tickFormat: d => d + '%'
      }}
      oLabel={d => (
        <text fontSize="8px" textAnchor="end" y={3} x={-3}>
          {d}
        </text>
      )}
      margin={{ left: 180, right: 0, bottom: 28, top: 40 }}
      oPadding={5}
    />
  </div>,
  document.getElementById('main')
);
